==> ejc-signaturemanage-api-3.0.1-20211221.074952-67-sources.jar: com.ejianc.business.signaturemanage/vo/SignMgrVO.java <==
package com.ejianc.business.signaturemanage.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 签章管理
 *
 * @author generator
 */
public class SignMgrVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long billId; // 业务id
    private java.lang.String billType; // 来源业务单据类型
    private java.lang.String billRefCode; // refcode
    private java.lang.Long sourceBillId; // 业务id（第三方系统返回的）
    private java.lang.Long sourceDocId; // 业务文档id（第三方系统返回的）
    private java.lang.Long billDocId; // 业务文件id
    private java.lang.String billDocumentName; // 业务文件名称
    private java.lang.String billDocumentType; // 业务文件类型
    private java.lang.String signRequirements; // 签署要求
    private java.lang.String creatorName; // 创建人名称
    private java.lang.String creatorContact; // 创建人联系方式
    private java.lang.String tenantName; // 发起方名称

    private List<SignMgrSignatoryVO> signMgrSignatoryEntities = new ArrayList<>(); // 签章管理-签署方子表

    /**
     * 业务id
     */
    public java.lang.Long getBillId() {
        return billId;
    }

    /**
     * 业务id
     */
    public void setBillId(java.lang.Long billId) {
        this.billId = billId;
    }

    /**
     * 来源业务单据类型
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * refcode
     */
    public String getBillRefCode() {
        return billRefCode;
    }

    /**
     * refcode
     */
    public void setBillRefCode(String billRefCode) {
        this.billRefCode = billRefCode;
    }

    /**
     * 来源业务单据类型
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }

    /**
     * 业务id（第三方系统返回的）
     */
    public java.lang.Long getSourceBillId() {
        return sourceBillId;
    }

    /**
     * 业务id（第三方系统返回的）
     */
    public void setSourceBillId(java.lang.Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    /**
     * 业务文档id（第三方系统返回的）
     */
    public java.lang.Long getSourceDocId() {
        return sourceDocId;
    }

    /**
     * 业务文档id（第三方系统返回的）
     */
    public void setSourceDocId(java.lang.Long sourceDocId) {
        this.sourceDocId = sourceDocId;
    }

    /**
     * 业务文件id
     */
    public java.lang.Long getBillDocId() {
        return billDocId;
    }

    /**
     * 业务文件id
     */
    public void setBillDocId(java.lang.Long billDocId) {
        this.billDocId = billDocId;
    }

    /**
     * 业务文件名称
     */
    public java.lang.String getBillDocumentName() {
        return billDocumentName;
    }

    /**
     * 业务文件名称
     */
    public void setBillDocumentName(java.lang.String billDocumentName) {
        this.billDocumentName = billDocumentName;
    }

    /**
     * 业务文件类型
     */
    public java.lang.String getBillDocumentType() {
        return billDocumentType;
    }

    /**
     * 业务文件类型
     */
    public void setBillDocumentType(java.lang.String billDocumentType) {
        this.billDocumentType = billDocumentType;
    }

    /**
     * 签署要求
     */
    public java.lang.String getSignRequirements() {
        return signRequirements;
    }

    /**
     * 签署要求
     */
    public void setSignRequirements(java.lang.String signRequirements) {
        this.signRequirements = signRequirements;
    }

    /**
     * 创建人名称
     */
    public String getCreatorName() {
        return creatorName;
    }

    /**
     * 创建人名称
     */
    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    /**
     * 创建人联系方式
     */
    public String getCreatorContact() {
        return creatorContact;
    }

    /**
     * 创建人联系方式
     */
    public void setCreatorContact(String creatorContact) {
        this.creatorContact = creatorContact;
    }

    /**
     * 发起方名称
     */
    public String getTenantName() {
        return tenantName;
    }

    /**
     * 发起方名称
     */
    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    /**
     * 签章管理-签署方子表
     */
    public List<SignMgrSignatoryVO> getSignMgrSignatoryEntities() {
        return signMgrSignatoryEntities;
    }

    /**
     * 签章管理-签署方子表
     */
    public void setSignMgrSignatoryEntities(List<SignMgrSignatoryVO> signMgrSignatoryEntities) {
        this.signMgrSignatoryEntities = signMgrSignatoryEntities;
    }

}

==> ejc-signaturemanage-api-3.0.1-20220223.033741-102-sources.jar: com.ejianc.business.signaturemanage/vo/SignMgrVO.java <==
package com.ejianc.business.signaturemanage.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 签章管理
 *
 * @author generator
 */
public class SignMgrVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long billId; // 业务id
    private java.lang.String billType; // 来源业务单据类型
    private String billCode; // 单据编号
    private String contractName; // 合同名称
    private java.lang.String billRefCode; // refcode
    private java.lang.Long sourceBillId; // 业务id（第三方系统返回的）
    private java.lang.Long sourceDocId; // 业务文档id（第三方系统返回的）
    private java.lang.Long billDocId; // 业务文件id
    private java.lang.String billDocumentName; // 业务文件名称
    private java.lang.String billDocumentType; // 业务文件类型
    private java.lang.String signRequirements; // 签署要求
    private java.lang.String creatorName; // 创建人名称
    private java.lang.String creatorContact; // 创建人联系方式
    private java.lang.String tenantName; // 发起方名称

    private List<SignMgrSignatoryVO> signMgrSignatoryEntities = new ArrayList<>(); // 签章管理-签署方子表

    /**
     * 业务id
     */
    public java.lang.Long getBillId() {
        return billId;
    }

    /**
     * 业务id
     */
    public void setBillId(java.lang.Long billId) {
        this.billId = billId;
    }

    /**
     * 来源业务单据类型
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 来源业务单据类型
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    /**
     * refcode
     */
    public String getBillRefCode() {
        return billRefCode;
    }

    /**
     * refcode
     */
    public void setBillRefCode(String billRefCode) {
        this.billRefCode = billRefCode;
    }

    /**
     * 业务id（第三方系统返回的）
     */
    public java.lang.Long getSourceBillId() {
        return sourceBillId;
    }

    /**
     * 业务id（第三方系统返回的）
     */
    public void setSourceBillId(java.lang.Long sourceBillId) {
        this.sourceBillId = sourceBillId;
    }

    /**
     * 业务文档id（第三方系统返回的）
     */
    public java.lang.Long getSourceDocId() {
        return sourceDocId;
    }

    /**
     * 业务文档id（第三方系统返回的）
     */
    public void setSourceDocId(java.lang.Long sourceDocId) {
        this.sourceDocId = sourceDocId;
    }

    /**
     * 业务文件id
     */
    public java.lang.Long getBillDocId() {
        return billDocId;
    }

    /**
     * 业务文件id
     */
    public void setBillDocId(java.lang.Long billDocId) {
        this.billDocId = billDocId;
    }

    /**
     * 业务文件名称
     */
    public java.lang.String getBillDocumentName() {
        return billDocumentName;
    }

    /**
     * 业务文件名称
     */
    public void setBillDocumentName(java.lang.String billDocumentName) {
        this.billDocumentName = billDocumentName;
    }

    /**
     * 业务文件类型
     */
    public java.lang.String getBillDocumentType() {
        return billDocumentType;
    }

    /**
     * 业务文件类型
     */
    public void setBillDocumentType(java.lang.String billDocumentType) {
        this.billDocumentType = billDocumentType;
    }

    /**
     * 签署要求
     */
    public java.lang.String getSignRequirements() {
        return signRequirements;
    }

    /**
     * 签署要求
     */
    public void setSignRequirements(java.lang.String signRequirements) {
        this.signRequirements = signRequirements;
    }

    /**
     * 创建人名称
     */
    public String getCreatorName() {
        return creatorName;
    }

    /**
     * 创建人名称
     */
    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    /**
     * 创建人联系方式
     */
    public String getCreatorContact() {
        return creatorContact;
    }

    /**
     * 创建人联系方式
     */
    public void setCreatorContact(String creatorContact) {
        this.creatorContact = creatorContact;
    }

    /**
     * 发起方名称
     */
    public String getTenantName() {
        return tenantName;
    }

    /**
     * 发起方名称
     */
    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    /**
     * 签章管理-签署方子表
     */
    public List<SignMgrSignatoryVO> getSignMgrSignatoryEntities() {
        return signMgrSignatoryEntities;
    }

    /**
     * 签章管理-签署方子表
     */
    public void setSignMgrSignatoryEntities(List<SignMgrSignatoryVO> signMgrSignatoryEntities) {
        this.signMgrSignatoryEntities = signMgrSignatoryEntities;
    }

}
